@@ -243,8 +243,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
             },this);
         },
         _makeUploadButton: function(cfg,btCfg,getFormData){
-            
-            
             var button;
             if (btCfg.btnClass == 'toolbar') {
                 button = new callbackery.ui.form.UploadToolbarButton(
@@ -264,18 +262,21 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                 }
             }
             var serverCall = callbackery.data.Server.getInstance();
-            button.addListener('changeSelection',function(e){
+            var key = btCfg.key;
+            var name = cfg.name;
+            button.addListener('changeFileSelection',function(e){
                 var fileList = e.getData();
                 var formData = getFormData();
                 if(formData && fileList) {
                     var form = new FormData();
-                    form.append('name',cfg.name);
-                    form.append('key',btCfg.key);
+                    form.append('name',name);
+                    form.append('key',key);
                     form.append('file',fileList[0]);
                     form.append('formData',qx.lang.Json.stringify(formData));
+                    var that = this;
                     serverCall.callAsyncSmart(function(cookie){
                         form.append('xsc',cookie);
-                        this._uploadForm(form);
+                        that._uploadForm(form);
                     },'getSessionCookie');
                 } else {
                     callbackery.ui.MsgBox.getInstance().error(
@@ -290,10 +291,12 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         },
 
         _uploadForm: function(form){
-            var req = new qx.io.request.Xhr("upload").set({
-                method: 'POST',
+            var req = new qx.io.request.Xhr("upload",'POST').set({
                 requestData: form
             });
+            // formData formats suff like that so we should set the 
+            // header appropriately
+            req.setRequestHeader('Content-Type','multipart/form-data');
             req.addListener('success',function(e) {
                 var response = req.getResponse();
                 if (response.exception){
